@@ -64,7 +64,7 @@ class CLI(cl1.CLI):
 
 		# user.
 		elif self.arguments.present(['--user']):
-			syst3m.defaults.check_operating_system(supported=["linux"])
+			syst3m.defaults.operating_system(supported=["linux"])
 
 			# initialize a user object.
 			user = syst3m.User(self.arguments.get("--user"))
@@ -109,7 +109,7 @@ class CLI(cl1.CLI):
 
 		# group.
 		elif self.arguments.present(['--group']):
-			syst3m.defaults.check_operating_system(supported=["linux"])
+			syst3m.defaults.operating_system(supported=["linux"])
 
 			# initialize a group object.
 			group = syst3m.Group(self.arguments.get("--group"))
@@ -162,7 +162,7 @@ class CLI(cl1.CLI):
 
 		# free disk space.
 		elif self.arguments.present(["--disk-space"]):
-			syst3m.defaults.check_operating_system(supported=["linux"])
+			syst3m.defaults.operating_system(supported=["linux"])
 			import shutil
 			import math
 			def size(size_bytes):
