@@ -5,6 +5,10 @@
 from syst3m.classes.config import *
 from syst3m.classes import objects
 
+# exceptions.
+class NetworkError(Exception):
+	pass
+
 # the cache object class.
 class Cache(objects.Object):
 	def __init__(self, path=None):
@@ -81,6 +85,8 @@ class WebServer(objects.Thread):
 		self.assign(serialized)
 		self.id = id.replace(" ","-")
 		self.tag = self.id.replace(" ","_")
+		try: self.log_level
+		except: self.log_level = 0
 	def set(self, group=None, id=None, data=None):
 		encoded = urllib.parse.urlencode({
 			"group":group,
@@ -191,15 +197,30 @@ class WebServer(objects.Thread):
 		self.__cache__.set(group=self.id, id="token", data=Formats.String("").generate(length=64, digits=True, capitalize=True))
 		self.app()
 		self.__cache__.set(group=self.id, id="daemon", data="*stopped*")
-	def fork(self):
-		print(f"Starting the {self.id}.")
+	def fork(self, timeout=15, sleeptime=1):
+		if self.running():
+			return r3sponse.error_response(f"The {self.id} is already running.")
+		if self.log_level <= 0:
+			print(f"Starting the {self.id}.")
 		serialized = self.dict()
 		serialized["path"] = self.__cache__.path
 		for i in ["__cache__","cache",]:
 			del serialized[i]
-		serialized = dict(serialized)
-		p = subprocess.Popen(["python3", f"{SOURCE_PATH}classes/cache/fork.py", "--serialized", f"'{serialized}'", "--syst3m-webserver-tag", self.tag])#, "2>", "/dev/null"])
-		time.sleep(3)
+		serialized = json.dumps(self.__serialize__(serialized, safe=True),indent=0)
+		command = ["python3", f"{SOURCE_PATH}classes/cache/fork.py", "--serialized", f"'{serialized}'", "--syst3m-webserver-tag", self.tag]
+		if self.log_level < 0:
+			command += [ "2>", "/dev/null"]
+		p = subprocess.Popen(command)
+		success = False
+		for i in range(int(timeout/sleeptime)):
+			if self.running():
+				success = True
+				break
+			time.sleep(sleeptime)
+		if success:
+			return r3sponse.success_response(f"Successfully started the {self.id}.")
+		else:
+			return r3sponse.error_response(f"The {self.id} is already running.")
 	def stop(self):
 		if not self.running(): 
 			return r3sponse.error_response(f"The {self.id} is not running.")
@@ -212,7 +233,7 @@ class WebServer(objects.Thread):
 				response = syst3m.kill(pid=pid)
 				if not response.success: return response
 		return r3sponse.error_response(f"Successfully stopped the {self.id}.")
-	def __serialize__(self, dict):
+	def __serialize__(self, dict, safe=False):
 		for key in list(dict.keys()):
 			value = dict[key]
 			if value in ["False", "false"]: dict[key] = False
@@ -223,6 +244,8 @@ class WebServer(objects.Thread):
 					int(value)
 					dict[key] = int(value)
 				except: a=1
+			if safe and isinstance(value, object):
+				del dict[key]
 		return dict
 	#def stop(self):
 	#	self.process.terminate()
