@@ -29,24 +29,6 @@ def __get_operating_system__():
 	if os in ["darwin"]: return "osx"
 	elif os in ["linux"]: return "linux"
 	else: raise ValueError(f"Unsupported operating system: [{os}].")
-def __get_source_path__(package_name, back=1):
-	executive_dir = str(pathlib.Path(__file__).absolute()).replace(os.path.basename(pathlib.Path(__file__)), '').replace("//","/")
-	if executive_dir[len(executive_dir)-1] == "/": executive_dir = executive_dir[:-1]
-	source, c = "/", 1
-	for id in executive_dir.split("/"):
-		if id == package_name:
-			if c == index:
-				source += id+"/"
-				break
-			else: c += 1
-		else: source += id+"/"
-	base = source[:-1].split("/")
-	base = source.replace(f'/{base[len(base)-1]}/', '/')
-	return source, base
-def __save_file__(path, data):
-	file = open(path, "w+") 
-	file.write(data)
-	file.close()
 def __check_alias__(
 	# the source name.
 	alias=None, 
@@ -78,9 +60,10 @@ def __check_alias__(
 		sys.exit(0)
 
 # source.
+from fil3s import Formats
 ALIAS = "syst3m"
 SOURCE_NAME = "syst3m"
-SOURCE_PATH, BASE = __get_source_path__(__file__, back=3)
+SOURCE_PATH = Formats.FilePath(__file__).base(back=3)
 OS = __get_operating_system__()
 
 # imports.
