@@ -26,18 +26,21 @@ def input(message, yes_no=False):
 
 # the loader object class.
 class Loader(threading.Thread):
-	def __init__(self, message, autostart=True, log_level=0):
+	def __init__(self, message, autostart=True, log_level=0, interactive=True):
 		threading.Thread.__init__(self)
 		self.message = self.__clean_message__(message)
 		self.last_message = str(self.message)
 		self.log_level = log_level
-		if autostart and self.log_level >= 0: 
+		self.interactive = interactive
+		if self.interactive and autostart and self.log_level >= 0: 
 			#self.start()
 			try:
 				self.start()
 			except KeyboardInterrupt as e:
 				self.stop(success=False)
 				raise KeyboardInterrupt(f"{e}")
+		elif not self.interactive:
+			print(self.message+".")
 	def run(self):
 		if self.log_level >= 0: 
 			self.running = True
@@ -66,17 +69,24 @@ class Loader(threading.Thread):
 				else:
 					success = False
 					message = "Error: "+response["error"]
-			self.running = False
-			for i in range(120):
-				if self.running == "stopped": break
-				time.sleep(0.5)
-			if self.running != "stopped": raise ValueError(f"Unable to stop loader [{self.message}].")
+			if self.interactive:
+				self.running = False
+				for i in range(120):
+					if self.running == "stopped": break
+					time.sleep(0.5)
+				if self.running != "stopped": raise ValueError(f"Unable to stop loader [{self.message}].")
 			if not quiet:
-				print(self.__empty_message__(length=len(f"{self.last_message} ...   ")), end="\r")
-				if success:
-					print(f"{message} ... done")
+				if self.interactive:
+					print(self.__empty_message__(length=len(f"{self.last_message} ...   ")), end="\r")
+					if success:
+						print(f"{message} ... done")
+					else:
+						print(f"{message} ... {color.red}failed{color.end}")
 				else:
-					print(f"{message} ... {color.red}failed{color.end}")
+					if success:
+						print(f"{message}. done")
+					else:
+						print(f"{message}. {color.red}failed{color.end}")
 	def mark(self, old_message=None, new_message=None, success=True, response=None):
 		if self.log_level >= 0: 
 			if response != None:
@@ -85,11 +95,17 @@ class Loader(threading.Thread):
 				else:
 					success = False
 			if old_message == None: old_message = self.message
-			print(self.__empty_message__(length=len(f"{self.last_message} ...   ")), end="\r")
-			if success:
-				print(f"{old_message} ... done")
+			if self.interactive:
+				print(self.__empty_message__(length=len(f"{self.last_message} ...   ")), end="\r")
+				if success:
+					print(f"{old_message} ... done")
+				else:
+					print(f"{old_message} ... {color.red}failed{color.end}")
 			else:
-				print(f"{old_message} ... {color.red}failed{color.end}")
+				if success:
+					print(f"{old_message}. done")
+				else:
+					print(f"{old_message}. {color.red}failed{color.end}")
 			if new_message != None: self.message = new_message
 	def hold(self):
 		if self.log_level >= 0: 
