@@ -82,9 +82,9 @@ class Defaults(object):
 			self.group = "staff"
 
 		#
-	def check_operating_system(self, supported=["osx", "linux"]):
-		if self.os in ["osx"] and self.os in supported: return "osx"
-		elif self.os in ["linux"] and self.os in supported: return "linux"
+	def operating_system(self, supported=["*"]):
+		if self.os in ["osx"] and ("*" in supported or self.os in supported): return "osx"
+		elif self.os in ["linux"] and ("*" in supported or self.os in supported): return "linux"
 		else: raise ValueError(f"Unsupported operating system: [{self.os}].")
 	def check_alias(self, 
 		# the source name.
@@ -121,17 +121,11 @@ class Defaults(object):
 				print(f"Check out the docs for more info $: {alias} -h")
 		if present:
 			quit()
-	def get_source_path(self, path, back=1):
+	def source_path(self, path, back=1):
 		return Formats.FilePath(path).base(back=back)
-	def get_log_level(self):
-		return cl1.get_argument("--log-level", required=False, empty=0)
+	def log_level(self, default=0):
+		return cl1.get_argument("--log-level", required=False, empty=default)
 	def pwd(self):
-		pwd = utils.__execute_script__("pwd").replace("\n","")
-		while True:
-			if len(pwd) > 0 and pwd[0] == "/": pwd = pwd[1:]
-			elif len(pwd) > 0 and pwd[len(pwd)-1] == "/": pwd = pwd[:-1]
-			elif " " in pwd: pwd = pwd.replace(" ","")
-			else: break
-		return f"/{pwd}/"
+		return Formats.FilePath(utils.__execute_script__("pwd").replace("\n","")).clean()
 # initialized classes.
 defaults = Defaults()
\ No newline at end of file
